#
# spec file for package python-ExifRead
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-ExifRead
Version:        3.0.0
Release:        2.1
Summary:        Module to read Exif metadata from TIFF and JPEG files
License:        BSD-3-Clause
URL:            https://pypi.python.org/pypi/ExifRead/%{version}
Source:         https://files.pythonhosted.org/packages/source/E/ExifRead/ExifRead-%{version}.tar.gz
Source1:        https://github.com/ianare/exif-samples/archive/master.tar.gz#/exif-samples-master.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A Python module to extract Exif metadata from TIFF and JPEG files.

%prep
%setup -q -n ExifRead-%{version} -a1

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/EXIF.py
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
find exif-samples-master -name "*.tiff" -o -name "*.jpg" -exec $python %{buildroot}%{_bindir}/EXIF.py-%{python_bin_suffix} {} \;
find exif-samples-master -name "*.tiff" -o -name "*.jpg" -exec $python %{buildroot}%{_bindir}/EXIF.py-%{python_bin_suffix} -dc {} \;
}

%post
%python_install_alternative EXIF.py

%postun
%python_uninstall_alternative EXIF.py

%files %{python_files}
%license LICENSE.txt
%doc README.rst ChangeLog.rst
%{python_sitelib}/exifread/
%{python_sitelib}/[Ee]xif[Rr]ead-%{version}*info
%python_alternative %{_bindir}/EXIF.py

%changelog
* Mon May  5 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Tue Aug  2 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to 3.0.0:
  * BREAKING CHANGE: Add type hints, which removes Python2 compatibility
  * Update make_string util to clean up bad values (#128)
  * Fix Olympus SpecialMode Unknown Values (#143)
  * Remove coding system from UserComment sequence only if it is valid (#147)
  * Fixes to orientation
  * Add some EXIF tags
  * Add support for PNG files (#159)
  * Fix for HEIC Unknown Parsers (#153)
  * Handle images that has corrupted headers/tags (#152)
* Fri Aug 27 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.3.2:
  * Fixes for HEIC files from Note10+ (#127) by Drew Perttula
  * Add missing EXIF OffsetTime tags (#126) by Étienne Pelletier
* Mon Sep  7 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.3.1:
  * Fix bug introduced with v2.3.0 in HEIC processing.
  * Add notice on Python2 EOL
  * Modernize code and improve testing, split up some huge functions
  * Added support for webp file format (#116) by Grzegorz Ruciński
  * Add linting
  * Added missing IFD data type; correct spelling mistake (#119) by Piero
    Toffanin
  * Add syntax highlight for README (#117) by John Lin
  * Add Python 3.8 to CI (#113) by 2*yo
  * make HEIC exif extractor much more compatible (#109) by Tony Guo
  * Add black level tag (#108)
  * Use list instead of tuple for classifiers (#107) by Florian Preinstorfer
  * Add support for Python 3.5, 3.6, 3.7
  * Drop official support for Python 2.6, 3.2, 3.3
  * Fix for string count equals 0 (issue #67)
  * Rebasing of struct pull requests: closes #54, closes #60 by Christopher
    Chavez
  * Refactor to use Python's struct module for packing/unpacking by Dave Jones
  * Support floating point fields" by Reed Nightingale (reedbn)
  * Raw images support by changing Tiff detection by xaumex
  * Fix GPS information erroneously None (#96) by Christopher Chavez
  * Initial HEIC support (Sam Rushing)
- Correct Source URL to not hardcode the version
- Use python_bin_suffix to call correct script during check
- Drop merged_pr_58.patch, included upstream
- Refresh exif-samples-master.tar.gz
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Apr 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Mark properly as BSD3c
* Mon Apr 15 2019 Jan Engelhardt <jengelh@inai.de>
- Fix missing quoting of wildcards in /usr/bin/find calls.
- Use noun phrase in summary. Ensure neutrality of description.
- Use %%setup for all unpacking.
* Fri Apr 12 2019 John Vandenberg <jayvdb@gmail.com>
- Add merged_pr_58.patch for Python 3 support
- Replace invalid pytest with real test suite
- Tidy spec file; use %%license, remove unnecessary devel
* Tue Nov 14 2017 marco.strigl@suse.com
- initial version submitted to :misc
* Tue Jun  7 2016 sbahling@suse.com
- Initial build. Version 2.1.2.
